@@ -30,7 +30,9 @@
 using namespace KDAV;
 
 DavItemCreateJob::DavItemCreateJob(const DavItem &item, QObject *parent)
-    : DavJobBase(parent), mItem(item), mRedirectCount(0)
+    : DavJobBase(parent)
+    , mItem(item)
+    , mRedirectCount(0)
 {
 }
 
@@ -64,10 +66,10 @@ QUrl DavItemCreateJob::itemUrl() const
 void DavItemCreateJob::davJobFinished(KJob *job)
 {
     KIO::StoredTransferJob *storedJob = qobject_cast<KIO::StoredTransferJob *>(job);
-    const int responseCode = storedJob->queryMetaData(QStringLiteral("responsecode")).isEmpty() ?
-                             0 :
-                             storedJob->queryMetaData(QStringLiteral("responsecode")).toInt();
-
+    const QString responseCodeStr = storedJob->queryMetaData(QStringLiteral("responsecode"));
+    const int responseCode = responseCodeStr.isEmpty()
+                             ? 0
+                             : responseCodeStr.toInt();
     if (storedJob->error()) {
         setLatestResponseCode(responseCode);
         setError(ERR_ITEMCREATE);
@@ -131,4 +133,3 @@ void DavItemCreateJob::itemRefreshed(KJob *job)
     }
     emitResult();
 }
-
